cgexplore.molecular.VaBene
==========================

.. currentmodule:: cgexplore.molecular

.. autoclass:: VaBene
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~VaBene.get_building_block
      ~VaBene.get_smiles
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~VaBene.present_beads
      ~VaBene.building_block
   
   